@@ -85,12 +85,13 @@ def new(package_name):
 @click.option('-f', '--force', is_flag=True, help="Don't check if git repo is clean.")
 @click.option('-r', '--revert', is_flag=True, help="Revert to the previous release.")
 @click.option('-p', '--prepare', type=click.Choice(['patch', 'minor', 'major']), help="Prepare next patch.")
-# @click.argument('branch_from', required=False)
+# @click.argument('alt_dir', required=False)
 #TODO @click.option('-c', '--commit', is_flag=True, help="Commit the patch to the hop_main branch")
-def patch(force, revert, prepare, branch_from=None):
+def patch(force, revert, prepare, alt_dir=None):
     """ Applies the next patch.
     """
-    # print('branch from', branch_from)
+    if alt_dir:
+        HOP.replica= Hop(alt_dir)
     if prepare:
         Patch(HOP).prep_next_release(prepare)
     elif revert:
@@ -101,10 +102,10 @@ def patch(force, revert, prepare, branch_from=None):
     sys.exit()
 
 
-@click.command()
+# @click.command('alt_dir', required=False)
 # @click.option('-d', '--dry-run', is_flag=True, help='Do nothing')
 # @click.option('-l', '--loop', is_flag=True, help='Run every patches to apply')
-def upgrade():
+def upgrade(alt_dir=None):
     """Apply one or many patches.
 
     switches to hop_main, pulls should check the tags
